@@ -102,7 +102,10 @@ class CFSOption(AbstractModel):
         :type LocalPath: str
         :param RemotePath: 文件系统远程挂载ip及路径
         :type RemotePath: str
-        :param Protocol: 文件系统协议类型，默认值NFS 3.0
+        :param Protocol: 文件系统协议类型，默认值NFS 3.0。
+<li>NFS 3.0。
+<li>NFS 4.0。
+<li>TURBO。
         :type Protocol: str
         :param StorageType: 文件系统存储类型，默认值SD；其中 SD 为通用标准型标准型存储， HP为通用性能型存储， TB为turbo标准型， TP 为turbo性能型。
         :type StorageType: str
@@ -310,15 +313,15 @@ class CreateClusterRequest(AbstractModel):
         :type Placement: :class:`tencentcloud.thpc.v20211109.models.Placement`
         :param ManagerNode: 指定管理节点。
         :type ManagerNode: :class:`tencentcloud.thpc.v20211109.models.ManagerNode`
-        :param ManagerNodeCount: 指定管理节点的数量。目前仅支持一个管理节点。
+        :param ManagerNodeCount: 指定管理节点的数量。默认取值：1。取值范围：1～2。
         :type ManagerNodeCount: int
         :param ComputeNode: 指定计算节点。
         :type ComputeNode: :class:`tencentcloud.thpc.v20211109.models.ComputeNode`
         :param ComputeNodeCount: 指定计算节点的数量。默认取值：0。
         :type ComputeNodeCount: int
-        :param SchedulerType: 调度器类型。<br><li>SGE：SGE调度器。
+        :param SchedulerType: 调度器类型。<br><li>SGE：SGE调度器。<br><li>SLURM：SLURM调度器。
         :type SchedulerType: str
-        :param ImageId: 指定有效的[镜像](https://cloud.tencent.com/document/product/213/4940)ID，格式形如`img-xxx`。目前仅支持公有镜像和自定义镜像。
+        :param ImageId: 指定有效的[镜像](https://cloud.tencent.com/document/product/213/4940)ID，格式形如`img-xxx`。目前仅支持公有镜像。
         :type ImageId: str
         :param VirtualPrivateCloud: 私有网络相关信息配置。
         :type VirtualPrivateCloud: :class:`tencentcloud.thpc.v20211109.models.VirtualPrivateCloud`
@@ -334,12 +337,21 @@ true：发送检查请求，不会创建实例。检查项包括是否填写了
 如果检查通过，则返回RequestId.
 false（默认）：发送正常请求，通过检查后直接创建实例
         :type DryRun: bool
-        :param AccountType: 域名字服务类型。<br><li>NIS：NIS域名字服务。
+        :param AccountType: 域名字服务类型。默认值：NIS
+<li>NIS：NIS域名字服务。
         :type AccountType: str
         :param ClusterName: 集群显示名称。
         :type ClusterName: str
         :param StorageOption: 集群存储选项
         :type StorageOption: :class:`tencentcloud.thpc.v20211109.models.StorageOption`
+        :param LoginNode: 已废弃。
+指定登录节点。
+        :type LoginNode: list of LoginNode
+        :param LoginNodeCount: 已废弃。
+指定登录节点的数量。默认取值：0。取值范围：0～10。
+        :type LoginNodeCount: int
+        :param Tags: 创建集群时同时绑定的标签对说明。
+        :type Tags: list of Tag
         """
         self.Placement = None
         self.ManagerNode = None
@@ -356,6 +368,9 @@ false（默认）：发送正常请求，通过检查后直接创建实例
         self.AccountType = None
         self.ClusterName = None
         self.StorageOption = None
+        self.LoginNode = None
+        self.LoginNodeCount = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -386,6 +401,19 @@ false（默认）：发送正常请求，通过检查后直接创建实例
         if params.get("StorageOption") is not None:
             self.StorageOption = StorageOption()
             self.StorageOption._deserialize(params.get("StorageOption"))
+        if params.get("LoginNode") is not None:
+            self.LoginNode = []
+            for item in params.get("LoginNode"):
+                obj = LoginNode()
+                obj._deserialize(item)
+                self.LoginNode.append(obj)
+        self.LoginNodeCount = params.get("LoginNodeCount")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -646,6 +674,74 @@ BANDWIDTH_PACKAGE：带宽包用户
         
 
 
+class LoginNode(AbstractModel):
+    """登录节点信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param InstanceChargeType: 节点[计费类型](https://cloud.tencent.com/document/product/213/2180)。<br><li>PREPAID：预付费，即包年包月<br><li>POSTPAID_BY_HOUR：按小时后付费<br><li>SPOTPAID：竞价付费<br>默认值：POSTPAID_BY_HOUR。
+        :type InstanceChargeType: str
+        :param InstanceChargePrepaid: 预付费模式，即包年包月相关参数设置。通过该参数可以指定包年包月节点的购买时长、是否设置自动续费等属性。若指定节点的付费模式为预付费则该参数必传。
+        :type InstanceChargePrepaid: :class:`tencentcloud.thpc.v20211109.models.InstanceChargePrepaid`
+        :param InstanceType: 节点机型。不同实例机型指定了不同的资源规格。
+<br><li>具体取值可通过调用接口[DescribeInstanceTypeConfigs](https://cloud.tencent.com/document/api/213/15749)来获得最新的规格表或参见[实例规格](https://cloud.tencent.com/document/product/213/11518)描述。
+        :type InstanceType: str
+        :param SystemDisk: 节点系统盘配置信息。若不指定该参数，则按照系统默认值进行分配。
+        :type SystemDisk: list of SystemDisk
+        :param DataDisks: 节点数据盘配置信息。若不指定该参数，则默认不购买数据盘。支持购买的时候指定21块数据盘，其中最多包含1块LOCAL_BASIC数据盘或者LOCAL_SSD数据盘，最多包含20块CLOUD_BASIC数据盘、CLOUD_PREMIUM数据盘或者CLOUD_SSD数据盘。
+        :type DataDisks: list of DataDisk
+        :param InternetAccessible: 节点数据盘配置信息。若不指定该参数，则默认不购买数据盘。支持购买的时候指定21块数据盘，其中最多包含1块LOCAL_BASIC数据盘或者LOCAL_SSD数据盘，最多包含20块CLOUD_BASIC数据盘、CLOUD_PREMIUM数据盘或者CLOUD_SSD数据盘。
+        :type InternetAccessible: list of InternetAccessible
+        :param InstanceName: 节点显示名称。<br><li>
+不指定节点显示名称则默认显示‘未命名’。
+最多支持60个字符。
+        :type InstanceName: str
+        """
+        self.InstanceChargeType = None
+        self.InstanceChargePrepaid = None
+        self.InstanceType = None
+        self.SystemDisk = None
+        self.DataDisks = None
+        self.InternetAccessible = None
+        self.InstanceName = None
+
+
+    def _deserialize(self, params):
+        self.InstanceChargeType = params.get("InstanceChargeType")
+        if params.get("InstanceChargePrepaid") is not None:
+            self.InstanceChargePrepaid = InstanceChargePrepaid()
+            self.InstanceChargePrepaid._deserialize(params.get("InstanceChargePrepaid"))
+        self.InstanceType = params.get("InstanceType")
+        if params.get("SystemDisk") is not None:
+            self.SystemDisk = []
+            for item in params.get("SystemDisk"):
+                obj = SystemDisk()
+                obj._deserialize(item)
+                self.SystemDisk.append(obj)
+        if params.get("DataDisks") is not None:
+            self.DataDisks = []
+            for item in params.get("DataDisks"):
+                obj = DataDisk()
+                obj._deserialize(item)
+                self.DataDisks.append(obj)
+        if params.get("InternetAccessible") is not None:
+            self.InternetAccessible = []
+            for item in params.get("InternetAccessible"):
+                obj = InternetAccessible()
+                obj._deserialize(item)
+                self.InternetAccessible.append(obj)
+        self.InstanceName = params.get("InstanceName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class LoginNodeOverview(AbstractModel):
     """登录节点概览。
 
@@ -880,6 +976,34 @@ CLOUD_PREMIUM：高性能云硬盘
         
 
 
+class Tag(AbstractModel):
+    """标签键值对。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Key: 标签键
+        :type Key: str
+        :param Value: 标签值
+        :type Value: str
+        """
+        self.Key = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class VirtualPrivateCloud(AbstractModel):
     """描述了VPC相关信息
 
